@@ -4,23 +4,23 @@ test_that('gCD run', {
 
     #Exploratory
     nfact <- 3
-    gCDresult <- gCD(holzinger, nfact)
-    gCDresult.outlier <- gCD(holzinger.outlier, nfact)
+    gCDresult <- gCD(holzinger, nfact, progress = FALSE)
+    gCDresult.outlier <- gCD(holzinger.outlier, nfact, progress = FALSE)
     expect_is(gCDresult, 'gCD')
     expect_is(plot(gCDresult), 'trellis')
     expect_is(gCDresult.outlier, 'gCD')
     expect_is(plot(gCDresult.outlier), 'trellis')
-    expect_equal(as.numeric(gCDresult$gCD[1:3]), c(0.0001543002, 0.0000634595, 0.0001105226), tolerance=1e-5)
+    expect_equal(as.numeric(gCDresult$gCD[1:3]), c(0.0020993686, 0.0008613305, 0.0013162123), tolerance=1e-5)
 
     #-------------------------------------------------------------------
     suppressMessages(model <- sem::specifyModel(file='sem-model/sem-model.txt', quiet=TRUE))
-    gCDresult <- suppressWarnings(gCD(holzinger, model))
-    gCDresult.outlier <- suppressWarnings(gCD(holzinger.outlier, model))
+    gCDresult <- suppressWarnings(gCD(holzinger, model, progress = FALSE))
+    gCDresult.outlier <- suppressWarnings(gCD(holzinger.outlier, model, progress = FALSE))
     expect_is(gCDresult, 'gCD')
     expect_is(plot(gCDresult), 'trellis')
     expect_is(gCDresult.outlier, 'gCD')
     expect_is(plot(gCDresult.outlier), 'trellis')
-    expect_equal(as.numeric(gCDresult$gCD[1:3]), c(1.339090e-05, 4.191384e-06, 3.585573e-05), tolerance=1e-5)
+    expect_equal(as.numeric(gCDresult$gCD[1:3]), c(0.14419229, 0.04918079, 0.42079870), tolerance=1e-5)
 
     #-------------------------------------------------------------------
     #Confirmatory with lavaan
@@ -28,9 +28,9 @@ test_that('gCD run', {
     F2 =~ MissNum + MxdArit + OddWrds
     F3 =~ Boots + Gloves + Hatchts'
 
-    gCDresult <- gCD(holzinger, model, orthogonal=TRUE)
-    gCDresult.outlier <- gCD(holzinger.outlier, model, orthogonal=TRUE)
-    expect_equal(as.numeric(gCDresult.outlier$gCD[1:3]), c(6.987431e-03, 1.713212e-05, 8.674694e-05),
+    gCDresult <- gCD(holzinger, model, orthogonal=TRUE, progress = FALSE)
+    gCDresult.outlier <- gCD(holzinger.outlier, model, orthogonal=TRUE, progress = FALSE)
+    expect_equal(as.numeric(gCDresult.outlier$gCD[1:3]), c(36.67371343, 0.05034515, 0.34999495),
                  tolerance = 1e-5)
     expect_is(gCDresult, 'gCD')
     expect_is(plot(gCDresult), 'trellis')
@@ -50,9 +50,9 @@ test_that('gCD categorical', {
     F2 =~ MissNum + MxdArit + OddWrds
     F3 =~ Boots + Gloves + Hatchts'
 
-    gCDresult <- suppressWarnings(gCD(dat, model, orthogonal=TRUE, ordered=colnames(dat)))
+    gCDresult <- suppressWarnings(gCD(dat, model, orthogonal=TRUE, progress = FALSE, ordered=colnames(dat)))
     expect_is(gCDresult, 'gCD')
-    expect_equal(as.numeric(head(gCDresult$gCD)), c(0.0007, 0.0005, 0.0069, 0.0005, 0.0012, 0.0038),
+    expect_equal(as.numeric(head(gCDresult$gCD)), c(0.45389878, 0.11746119, 0.15885323, 0.07169155, 0.30643962, 0.15728745),
                  tolerance = 1e-2)
 
     #model <- mirt::mirt.model('F1 = 1-3
