@@ -1,7 +1,7 @@
 context('obs.resid')
 
 test_that('obs.resid run', {
-    
+
     #Exploratory
     nfact <- 3
     ORresult <- obs.resid(holzinger, nfact)
@@ -11,24 +11,24 @@ test_that('obs.resid run', {
     expect_is(ORresult, 'obs.resid')
     expect_is(ORresult.outlier, 'obs.resid')
     expect_is(plot(ORresult), 'trellis')
-    expect_is(plot(ORresult.outlier), 'trellis')    
-    
-    #-------------------------------------------------------------------    
-    suppressMessages(model <- sem::specifyModel(file='sem-model/sem-model.txt', quiet=TRUE))    
-    ORresult <- obs.resid(holzinger, model)
-    ORresult.outlier <- obs.resid(holzinger.outlier, model)
+    expect_is(plot(ORresult.outlier), 'trellis')
+
+    #-------------------------------------------------------------------
+    suppressMessages(model <- sem::specifyModel(file='sem-model/sem-model.txt', quiet=TRUE))
+    ORresult <- suppressWarnings(obs.resid(holzinger, model))
+    ORresult.outlier <- suppressWarnings(obs.resid(holzinger.outlier, model))
     expect_equal(ORresult$std_res[1:3], c(0.2548177, -0.5300287, -1.8518586),
                  tolerance = 1e-5)
     expect_is(ORresult, 'obs.resid')
     expect_is(ORresult.outlier, 'obs.resid')
     expect_is(plot(ORresult), 'trellis')
     expect_is(plot(ORresult.outlier), 'trellis')
-    
-    #-------------------------------------------------------------------    
+
+    #-------------------------------------------------------------------
     model <- 'F1 =~  Remndrs + SntComp + WrdMean
     F2 =~ MissNum + MxdArit + OddWrds
     F3 =~ Boots + Gloves + Hatchts'
-    
+
     obs.resid2 <- obs.resid(holzinger, model, orthogonal=TRUE)
     obs.resid2.outlier <- obs.resid(holzinger.outlier, model, orthogonal=TRUE)
     expect_equal(ORresult$std_res[1:3], c(0.2548177, -0.5300287, -1.8518586),
